@@ -2,8 +2,11 @@ package CIF::Client::Plugin::Csv;
 
 use Regexp::Common qw/net/;
 
+sub type { return 'output'; }
+
 sub write_out {
     my $self = shift;
+    my $config = shift;
     my @array = @_;
     my @header = keys(%{$array[0]});
     @header = sort { $a cmp $b } @header;
